@@ -1,5 +1,5 @@
 package ZMQ::Raw::Loop;
-$ZMQ::Raw::Loop::VERSION = '0.17';
+$ZMQ::Raw::Loop::VERSION = '0.18';
 use strict;
 use warnings;
 use Carp;
@@ -42,7 +42,7 @@ ZMQ::Raw::Loop - Loop class
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -177,6 +177,11 @@ sub _add_timer
 	$timer->loop ($this);
 	$this->poller->add ($timer->timer->socket, ZMQ::Raw->ZMQ_POLLIN);
 
+	if (!$timer->running)
+	{
+		$timer->reset();
+	}
+
 	push @{$this->timers}, $timer;
 }
 
