@@ -1,5 +1,5 @@
 package ZMQ::Raw::Timer;
-$ZMQ::Raw::Timer::VERSION = '0.17';
+$ZMQ::Raw::Timer::VERSION = '0.18';
 use strict;
 use warnings;
 use Carp;
@@ -13,7 +13,7 @@ ZMQ::Raw::Timer - ZeroMQ Timer class
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -60,6 +60,10 @@ Reset the timer
 
 Cancel the timer
 
+=head2 expire( )
+
+Expire the timer
+
 =head2 socket( )
 
 Get the underlying L<C<ZMQ::Raw::Socket>> that will be readable
